function cobra_param=cobra_options(varargin);
% COBRA_OPTIONS - set cobra options  
%   option                : Desciption [default]
%  --- preprocess parameters ---
%  'PreprocBlurKernel'    : Size of the blurring kernel (mm of the fwhm) used in preprocessing the
%                           fMRI-data (typically used prior to motion correction).
%                           Use: [], empty if no blurring was used. [6]
%  --- COBRA parameters ---
%  'DerivativesKernel'    : Size of the derivative kernel (fwhm in mm) to create the derivatives
%                           from the phase-maps, which will be used to determine the VFS. The results
%                           are relatively stable across a small range of fwhms (2-4mm), but outside
%                           this range artifacts may occur. If the fMRI resolution is very different
%                           from mine (4mm3), I suggest trying 3/4*[x y z] resolutions. [3],
%  'AnatDerKernel'        : Same as 'DerivativesKernel' for anatomical data [3],
%  'SmoothDerivatives'    : Smooth derivative files  [1](true)
%  'WeightDerivatives'    : Weight smoothing derivative process [1](true)
%  'NumberPhaseShifts'    : Number of phase shifts in derivative computation [3]
%  'Add'                  : Add instead of averaging phase shifted derivative files [1](true)
%  'RetFastMeth'          : Not working any more. Potential shortcut in the data analysis that
%                           creatly reduces processing time and introduces artifacts. [0](false)
%  'GetSecondDers'        : Not supported anymore [0](false)
%  'GetGradientMap'       : Used for debugging purposes [0](false)
%  'LikeFile'             : File to take dimensions from to resample data.
%                           Suggest providing the anatomical file at resolution that that the output
%                           data is required in ([]).  Note that the whole fMRI-scan is resampled to
%                           that resolution (main time consumer and disk hogger) I personally
%                           transform the data in Tal-space and use only the occipital lobe. For an
%                           example see: Cobra/Example/SubjectSD_t1w_occ.mnc.gz The data does not
%                           need to be resampled to Tal-space but I strongly recommend resampling it
%                           to a higher resolution. [[]]
%  --- thresholding parameters --- 
%      all are not used anymore - may speed things up and introduce artifacts.
%  'IntThresh'            : Intensity threshold [0]
%  'FftThresh'            : Fft threshold [0]
%  'GradThresh'           : Gradient threshold [0]
%  'FftMagThresh'         : Fft magnitude threshold [0]
%  --- other parameters ---
%  'TmpOutputBase'        : Temporary output names
%                           [strvcat('phase2angle_',...
%                                     'phase1ecc___',...
%                                     'anatomy');]
%  'RetTmpDir'            : Temporary working directory.
%                           Should have enough disk space available. [pwd]
%  'KeepTmp'              : Keep temporary workspace [0](false)

% ---------------------------------
% Copyright (c) 2004 Serge Dumoulin
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License version 2
% as published by the Free Software Foundation.
% ---------------------------------


TRUE                 = 1;
FALSE                = 0;

%--------------------------------------------------------------
%--- set default COBRA parameters
%--------------------------------------------------------------

%--- Parameters related to previous processing steps or scanning procedures:
% preprocess parameters:
cobra_param.preproc_blur_kernel  = 6;

%--- COBRA Parameters ([] =  estimate from data, not always supported though):

% derivative parameters
cobra_param.derivatives_kernel   = 3;
cobra_param.anat_der_kernel      = 3;
cobra_param.smooth_derivatives   = TRUE;
cobra_param.weight_derivatives   = TRUE;
cobra_param.number_phase_shifts  = 3;
cobra_param.add                  = TRUE;
cobra_param.ret_fast_meth        = FALSE; % a lot less
% accurate and not supported anymore

cobra_param.get_second_ders      = FALSE;
cobra_param.get_gradient_map     = FALSE;

% resample parameters if other than anatomy file(=[])
cobra_param.like_file            = []; % obsolete

% thresholding parameters
cobra_param.int_thresh           = 0;
cobra_param.fft_thresh           = 0;
cobra_param.grad_thresh          = 0;
cobra_param.fft_mag_thresh       = 0;

cobra_param.tmpoutputbase        = strvcat('phase2angle_',...
                                           'phase1ecc___',...
                                           'anatomy');

%--------------------------------------------------------------
%--- no effect on functioning of the algorithm
%--------------------------------------------------------------

cobra_param.ret_tmp_dir          = pwd;
cobra_param.cur_dir              = pwd;
cobra_param.keep_tmp             = FALSE;

%--------------------------------------------------------------
%--- now check and reset defaults
%--------------------------------------------------------------

% 'argname' 'cobra_param fieldname'
checknames = {   'PreprocBlurKernel'       'preproc_blur_kernel'
                 'DerivativesKernel'       'derivatives_kernel'
                 'AnatDerKernel'           'anat_der_kernel'
                 'SmoothDerivatives'       'smooth_derivatives'
                 'WeightDerivatives'       'weight_derivatives'
                 'NumberPhaseShifts'       'number_phase_shifts'
                 'Add'                     'add'
                 'RetFastMeth'             'ret_fast_meth'
                 'GetSecondDers'           'get_second_ders'
                 'GetGradientMap'          'get_gradient_map'
                 'LikeFile'                'like_file'
                 'IntThresh'               'int_thresh'
                 'FftThresh'               'fft_thresh'
                 'GradThresh'              'grad_thresh'
                 'FftMagThresh'            'fft_mag_thresh'
                 'TmpOutputBase'           'tmpoutputbase'
                 'RetTmpDir'               'ret_tmp_dir'
                 'KeepTmp'                 'keep_tmp'};


for ii=1:2:length(varargin),
    cur_arg=varargin{ii};
    cur_set=varargin{ii+1};
    
    for n=1:size(checknames,1)
        if strcmp(cur_arg,checknames(n,1)),
            cobra_param = setfield(cobra_param,char(checknames(n,2)),cur_set);
        end;
    end;
end;


