function cobra_phaseanalysis(cobra_param);
% COBRA_PHASEANALYSIS - wrapper for cobra's phase analysis (calls phase_fit)
% cobra_phaseanalysis(cobra_param);
%  do resampling to tal-space and phase analysis 


% ---------------------------------
% Copyright (c) 2003 Serge Dumoulin
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License version 2
% as published by the Free Software Foundation.
% ---------------------------------


tmpfile =[cobra_param.ret_tmp_subdir 'tmpfile.mnc'];
tmpfile2=[cobra_param.ret_tmp_subdir 'tmpfile2.mnc'];
tmpfile3=[cobra_param.ret_tmp_subdir 'tmpfile3.mnc'];

ResFile   = cobra_param.like_file;
transfile = cobra_param.xfm_file;

for loop = 1:2,
  % which files
  if loop == 1,
    files = cobra_param.angle_file;
  else,
    files = cobra_param.ecc_file;
  end;
  
  if ~isempty(files),
    % if different directions present
    if sum(cobra_param.directions(:,loop))==sum(abs(cobra_param.directions(:,loop))),
      nloop2 = 1;
      ext = [];
    else,
      nloop2 = 2;
    end;
    
    for loop2=1:nloop2;
      if loop2 == 1 & nloop2 ==2,
        keep = cobra_param.directions(:,loop);
        keep = keep(1:size(files,1));
        keep = find(keep== 1);
        file = files(keep,:);
        ext  = '_p1';
      elseif loop2 == 2 & nloop2 ==2,
        keep = cobra_param.directions(:,loop);
        keep = keep(1:size(files,1));
        keep = find(keep==-1);
        file = files(keep,:);
        ext  = '_m1';
      else,
        file = files;
      end;
      
      % loop over files
      for n=1:size(file,1),
        disp(sprintf('[%s]: Resampling file %d of %d',mfilename,n,size(file,1)));
        if n==1,
          if ~isempty(transfile),
            if size(transfile,1) == 1,
              system(['mincresample -clobber ' file(n,:) ' ' ...
                      tmpfile ' -like ' ResFile ' -transf ' ...
                      transfile]);
            else,
              system(['mincresample -clobber ' file(n,:) ' ' ...
                      tmpfile ' -like ' ResFile ' -transf ' ...
                      transfile(n,:)]);
            end;
          else,
            system(['mincresample -clobber ' file(n,:) ' ' ...
                    tmpfile ' -like ' ResFile]);
          end;
        else,
          if ~isempty(transfile),
            if size(transfile,1) == 1,
              system(['mincresample -clobber ' file(n,:) ' ' ...
                      tmpfile2 ' -like ' ResFile ' -transf ' transfile]);
            else,
              system(['mincresample -clobber ' file(n,:) ' ' ...
                      tmpfile2 ' -like ' ResFile ' -transf ' transfile(n,:)]);
            end;
          else,
            system(['mincresample -clobber ' file(n,:) ' ' ...
                    tmpfile2 ' -like ' ResFile]);
          end;
          system(['mincmath -add -clobber ' tmpfile ' ' tmpfile2 ...
                  ' ' tmpfile3]);
          delete(tmpfile);
          copyfile(tmpfile3,tmpfile);
          delete(tmpfile2);
          delete(tmpfile3);
        end;
      end;
      
      
      outbase=[cobra_param.ret_tmp_subdir ...
               cobra_param.tmpoutputbase(loop,: ) ext];
      % phase analysis (on already resampled data)
      phase_fit(tmpfile,...
                cobra_param.stim_freq(loop),...
                cobra_param.int_thresh,...
                cobra_param.fft_thresh,...
                outbase,...
                cobra_param.blanks(loop),...
                cobra_param.add_outputs(2),...
                cobra_param.add_outputs(3));
      delete(tmpfile);
    end;
    
    if ~isempty(ext),
      base=[cobra_param.ret_tmp_subdir ...
            cobra_param.tmpoutputbase(loop,: )];
      combine_phase_files([base '_p1_fft_phase.mnc'],...
                          [base '_m1_fft_phase.mnc'],...
                          base,[],...
                          [base '_p1_fft_magnitude.mnc'],...
                          [base '_m1_fft_magnitude.mnc']);
      copyfile([base '_avg.mnc'],[base '_fft_phase.mnc']);
      delete([base '_p1_fft_phase.mnc']);
      delete([base '_m1_fft_phase.mnc']);
      system(['mincaverage -clobber ' ...
              base '_p1_fft_magnitude.mnc ' ...
              base '_m1_fft_magnitude.mnc ' ...
              base '_fft_magnitude_tmp.mnc ']);
      system(['mincmath -clobber -mult -const 1.4142 ' ...
              base '_fft_magnitude_tmp.mnc ' ...
              base '_fft_magnitude.mnc ']);
      delete([base '_fft_magnitude_tmp.mnc']);
      
      if cobra_param.add_outputs(2),
        % average the two t-maps together and 
        % roughly) correct for the averaging process
        system(['mincaverage -clobber ' ...
                base '_p1_dspear_tmap.mnc ' ...
                base '_m1_dspear_tmap.mnc ' ...
                base '_dspear_tmap_tmp.mnc ']);
        system(['mincmath -clobber -mult -const 1.4142 ' ...
                base '_dspear_tmap_tmp.mnc ' ...
                base '_dspear_tmap.mnc']);
        delete([base '_dspear_tmap_tmp.mnc']);
      end;
    end;    
  end;
end;








