function combine_phase_files(file1,file2,outputbase,except,weight1,weight2);
% COMBINE_PHASE_FILES - combine files with opposite phases
% combine_phase_files(file1,file2,outputbase,except,weight1,weight2);
%  optionally weight the averaging process by the magnitude files

if nargin < 3,
  help(mfilename);
  return;
end;
if nargin < 4 | isempty(except),
  except = -3.5;
end;
if nargin < 5,
  weight1 = [];
end;
if nargin < 6,
  weight2 = [];
end;

tic;

% open files
h1 = openimage(deblank(file1));
h2 = openimage(deblank(file2));
ns = getimageinfo(h1,'NumSlices');
ih = getimageinfo(h1,'ImageHeight');
iw = getimageinfo(h1,'ImageWidth');

v1 = getimages(h1,1:ns);
v2 = getimages(h2,1:ns);

closeimage(h1);
closeimage(h2);

% flip v2
v2 = v2 .* -1;

% find shortest distance
vd = (v2-v1);
ii = find(vd> pi);
while ~isempty(ii),
    vd(ii)= vd(ii) - (2*pi);
    ii = find(vd> pi);
end;
ii = find(vd<-pi);
while ~isempty(ii),
    vd(ii) = vd(ii) + (2*pi);
    ii = find(vd<-pi);
end;
vd(v1==except) = except;
vd(v2==except) = except;

% open masks
if ~isempty(weight1) & ~isempty(weight2),
  h1 = openimage(deblank(weight1));
  h2 = openimage(deblank(weight2));
  
  w1 = getimages(h1,1:ns);
  w2 = getimages(h2,1:ns);
  
  closeimage(h1);
  closeimage(h2);
else,
  w1=1;
  w2=1;
end;

% now average
vc = v1 + (vd .* (w2./(w1+w2)));
ii = find(vc> pi);
while ~isempty(ii),
    vc(ii)= vc(ii) - (2*pi);
    ii = find(vc> pi);
end;
ii = find(vc<-pi);
while ~isempty(ii),
    vc(ii) = vc(ii) + (2*pi);
    ii = find(vc<-pi);
end;
vc(v1==except) = except;
vc(v2==except) = except;

% clean up
clear v1 v2;

% save outputs
outfile = [outputbase '_avg.mnc'];
nh = newimage(outfile,[0 ns ih iw],file1);
putimages(nh,vc,1:ns);
closeimage(nh);

outfile = [outputbase '_dif.mnc'];
nh = newimage(outfile,[0 ns ih iw],file1);
putimages(nh,vd,1:ns);
closeimage(nh);

disp(sprintf('[%s]: elapsed time = %d seconds.',mfilename,round(toc)));
